pub fn get_actor_unchecked<T: Actor>(id: &Ustr) -> ActorRef<T>Expand description
Returns a guard providing mutable access to the registered actor of type T.
The returned ActorRef holds an Rc to keep the actor alive, preventing
use-after-free if the actor is removed from the registry.
Panics
- Panics if no actor with the specified
idis found in the registry. - Panics if the stored actor is not of type
T.