pub fn try_get_actor_unchecked<T: Actor>(id: &Ustr) -> Option<ActorRef<T>>Expand description
Attempts to get a guard providing mutable access to the registered actor.
Returns None if the actor is not found or the type doesn’t match.
See get_actor_unchecked for aliasing and thread-safety constraints.